@@ -115,6 +115,7 @@ map_to_grid <- function(transform, target, row, plan, graph) {
     target, grid, cols = sub_cols, id = dsl_id(transform)
   )
   out <- data.frame(target = new_targets, stringsAsFactors = FALSE)
+  grid$.id_chr <- sprintf("\"%s\"", new_targets)
   for (col in setdiff(old_cols(plan), c("target", "transform"))) {
     if (is.language(row[[col]][[1]])) {
       out[[col]] <- grid_subs(row[[col]][[1]], grid)
@@ -122,6 +123,7 @@ map_to_grid <- function(transform, target, row, plan, graph) {
       out[[col]] <- row[[col]][[1]]
     }
   }
+  grid$.id_chr <- NULL
   cbind(out, grid)
 }
 
@@ -181,6 +183,7 @@ new_targets <- function(target, grid, cols, id) {
     return(make_unique(make.names(out, unique = FALSE, allow_ = TRUE)))
   }
   suffixes <- apply(grid, 1, paste, collapse = "_")
+  suffixes <- gsub("\"", "", suffixes, fixed = TRUE)
   out <- paste0(target, "_", suffixes)
   make_unique(make.names(out, unique = FALSE, allow_ = TRUE))
 }
