@@ -194,7 +194,7 @@ test_with_dir(
     )
   })
   expect_true(all(letters[1:4] %in% cached()))
-  expect_true(all(letters[1:4] %in% con$plan$target))
+  expect_true(all(letters[1:4] %in% names(con$layout)))
 })
 
 test_with_dir("plans can start with bad symbols", {
@@ -203,18 +203,8 @@ test_with_dir("plans can start with bad symbols", {
     target = c("a'x'", "b'x'", "_a", "a^-.*"),
     command = 1)
   y <- drake_config(x)
-  expect_equal(y$plan$target, c("a.x.", "b.x.", "X_a", "a...."))
-})
-
-test_with_dir("issue 187 on Github (from Kendon Bell)", {
-  skip_on_cran() # CRAN gets whitelist tests only (check time limits).
-  test <- drake_plan(test = run_it(wc__))
-  out <- evaluate_plan(test, rules = list(wc__ = list(1:4, 5:8, 9:12)))
-  out2 <- weak_tibble(
-    target = c("test_1.4", "test_5.8", "test_9.12"),
-    command = c("run_it(1:4)", "run_it(5:8)", "run_it(9:12)")
-  )
-  equivalent_plans(out, out2)
+  out <- sort(c("a.x.", "b.x.", "X_a", "a...."))
+  expect_true(all(out %in% names(y$layout)))
 })
 
 test_with_dir("can use semicolons for multi-line commands", {
@@ -341,13 +331,26 @@ test_with_dir("bind_plans()", {
     bind_plans(list(list(plan1), list(plan2), list(plan3))),
     exp
   )
+  equivalent_plans(
+    bind_plans(,drake_plan(x = 1, y = 2),,drake_plan(z = 3),,,), # nolint
+    drake_plan(x = 1, y = 2, z = 3)
+  )
 })
 
 test_with_dir("spaces in target names are replaced only when appropriate", {
   skip_on_cran() # CRAN gets whitelist tests only (check time limits).
-  pl <- drake_plan(a = x__, file_out("x__"))
-  pl <- evaluate_plan(
-    pl, wildcard = "x__", values = c("{b  \n  x; y}", "{a; x}")
+  pl <- drake_plan(
+    a_.b.....x..y. = {
+      b
+      x
+      y
+    },
+    a_.a..x. = {
+      a
+      x
+    },
+    drake_target_1_.b.....x..y. = file_out("{b  \n  x; y}"),
+    drake_target_1_.a..x. = file_out("{a; x}")
   )
   expect_equal(
     sort(pl$target),
@@ -360,41 +363,6 @@ test_with_dir("spaces in target names are replaced only when appropriate", {
   )
 })
 
-test_with_dir("conflicts in wildcard names/values", {
-  skip_on_cran() # CRAN gets whitelist tests only (check time limits).
-  plan <- drake_plan(a = 1, b = 2)
-  rules1 <- list(plant = 1:2, seed = 3:4, plantseed = 5:6)
-  rules2 <- list(
-    plant = c("grow", "tall"),
-    bean = c("legume", "stalk"),
-    example = c("bean", "stalk")
-  )
-  expect_error(
-    evaluate_plan(plan, rules = rules1), regexp = "wildcard name")
-  expect_error(
-    evaluate_plan(plan, rules = rules2), regexp = "replacement value")
-})
-
-test_with_dir("bad 'columns' argument to evaluate_plan()", {
-  plan <- drake_plan(
-    x = target("always", cpu = "any"),
-    y = target("any", cpu = "always"),
-    z = target("any", cpu = "any")
-  )
-  expect_error(
-    evaluate_plan(plan, wildcard = "any", values = 1:2, columns = "target"),
-    regexp = "argument of evaluate_plan"
-  )
-  expect_error(
-    evaluate_plan(plan, wildcard = "any", values = 1:2, columns = "nobodyhere"),
-    regexp = "not in the plan"
-  )
-  equivalent_plans(
-    plan,
-    evaluate_plan(plan, wildcard = "any", values = 1:2, columns = NULL)
-  )
-})
-
 test_with_dir("drake_plan_call() produces the correct calls", {
   skip_on_cran()
   skip_if_not_installed("styler")
